@@ -11,7 +11,7 @@ Date:2019/9/24 15:11
 import requests
 import json
 from aip import AipSpeech
-from Shenma.sound import *
+from Shenma.speech import *
 
 
 
@@ -55,3 +55,4 @@ class Translation(object):
 
 
 
+
